@@ -8,6 +8,7 @@ use Elive::Entity;
 use base qw{ Elive::Entity };
 
 use Elive::Entity::Role;
+use Elive::Util;
 
 __PACKAGE__->entity_name('User');
 __PACKAGE__->collection_name('Users');
@@ -153,7 +154,7 @@ Id of 0, i.e. system administrator accounts
 
 sub update {
     my $self = shift;
-    my %data = %{shift() || {}};
+    my %update_data = %{shift() || {}};
     my %opt = @_;
 
     unless ($opt{force}) {
@@ -161,16 +162,21 @@ sub update {
 	    if ($self->role->stringify <= 0);
     }
 
-    my $password = $data{loginPassword};
-
-    my $ret = $self->SUPER::update( \%data, %opt );
-
+    $self->set( %update_data)
+	if (keys %update_data);
+    
     #
-    # seems we have to insert a record, then set the password
+    # A password change requires special handling
     #
-    if (defined $password and $password ne '') {
-	$self->change_password($password);
-    }
+    my @changed = $self->is_changed;
+    my @changed1  = grep {$_ ne 'loginPassword'} @changed;
+    my $password_changed = @changed != @changed1;
+    my $password = delete $self->{loginPassword};
+
+    my $ret = $self->SUPER::update( undef, %opt, changed => \@changed1 );
+
+    $self->change_password($password)
+	if $password_changed;
 
     return $ret;
 }
@@ -189,7 +195,7 @@ sub change_password {
     my %opt = @_;
 
     $self->SUPER::update({loginPassword => $new_password},
-			 adapter => 'ChangePasswordCommand',
+			 adapter => 'changePassword',
 			 %opt,
 	)
 	if (defined $new_password && $new_password ne '');
@@ -217,7 +223,17 @@ sub delete {
 
     unless ($opt{force}) {
 	die "Cowardly refusing to delete system admin account for ".$self->loginName.": (pass force => 1 to override)"
-	    if ($self->role <= 0);
+	    if (Elive::Util::string($self->role) == 0);
+
+	my $connection = $opt{connection} || $self->connection;
+
+	my $login = $connection->login;
+	die "Not loggged in" unless $login;
+	#
+	# Less cowardly, methinks!
+	#
+	die "Refusing to delete the login user ".$login->loginName.": (pass force => 1 to override)"
+	    if $login->userId eq $self->userId;   
     }
 
     return $self->SUPER::delete( %opt );
